SUB_API: float = 10.0  # redvox-api-1000 -> build_protos.sh -> insert_sub_api.py on 2022-07-07 00:07:12.686182

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/redvox_api_m/redvox_api_m.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#src/redvox_api_m/redvox_api_m.proto\x12\x0credvox_api_m\"\xecs\n\rRedvoxPacketM\x12\x0b\n\x03\x61pi\x18\x01 \x01(\x02\x12\x0f\n\x07sub_api\x18\x02 \x01(\x02\x12K\n\x13station_information\x18\x03 \x01(\x0b\x32..redvox_api_m.RedvoxPacketM.StationInformation\x12I\n\x12timing_information\x18\x04 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.TimingInformation\x12\x34\n\x07sensors\x18\x05 \x01(\x0b\x32#.redvox_api_m.RedvoxPacketM.Sensors\x12>\n\revent_streams\x18\x06 \x03(\x0b\x32\'.redvox_api_m.RedvoxPacketM.EventStream\x12;\n\x08metadata\x18\x07 \x03(\x0b\x32).redvox_api_m.RedvoxPacketM.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd1$\n\x12StationInformation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x61uth_id\x18\x04 \x01(\t\x12\x0c\n\x04make\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12\x41\n\x02os\x18\x07 \x01(\x0e\x32\x35.redvox_api_m.RedvoxPacketM.StationInformation.OsType\x12\x12\n\nos_version\x18\x08 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\t \x01(\t\x12\x12\n\nis_private\x18\n \x01(\x08\x12P\n\x0c\x61pp_settings\x18\x0b \x01(\x0b\x32:.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings\x12V\n\x0fstation_metrics\x18\x0c \x01(\x0b\x32=.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics\x12P\n\x0cservice_urls\x18\r \x01(\x0b\x32:.redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls\x12N\n\x08metadata\x18\x0e \x03(\x0b\x32<.redvox_api_m.RedvoxPacketM.StationInformation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xe1\x01\n\x0bServiceUrls\x12\x13\n\x0b\x61uth_server\x18\x01 \x01(\t\x12\x14\n\x0csynch_server\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x63quisition_server\x18\x03 \x01(\t\x12Z\n\x08metadata\x18\x04 \x03(\x0b\x32H.redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf9\x0c\n\x0eStationMetrics\x12=\n\ntimestamps\x18\x01 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12_\n\x0cnetwork_type\x18\x02 \x03(\x0e\x32I.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.NetworkType\x12j\n\x12\x63\x65ll_service_state\x18\x03 \x03(\x0e\x32N.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.CellServiceState\x12\x43\n\x10network_strength\x18\x04 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12>\n\x0btemperature\x18\x05 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12:\n\x07\x62\x61ttery\x18\x06 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x42\n\x0f\x62\x61ttery_current\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12@\n\ravailable_ram\x18\x08 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x41\n\x0e\x61vailable_disk\x18\t \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x42\n\x0f\x63pu_utilization\x18\n \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12]\n\x0bpower_state\x18\x0b \x03(\x0e\x32H.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.PowerState\x12\x62\n\x0ewifi_wake_lock\x18\x0c \x03(\x0e\x32J.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.WifiWakeLock\x12_\n\x0cscreen_state\x18\r \x03(\x0e\x32I.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.ScreenState\x12\x44\n\x11screen_brightness\x18\x0e \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12]\n\x08metadata\x18\x0f \x03(\x0b\x32K.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x0bNetworkType\x12\x13\n\x0fUNKNOWN_NETWORK\x10\x00\x12\x0e\n\nNO_NETWORK\x10\x01\x12\x08\n\x04WIFI\x10\x02\x12\x0c\n\x08\x43\x45LLULAR\x10\x03\x12\t\n\x05WIRED\x10\x04\"C\n\x0cWifiWakeLock\x12\x08\n\x04NONE\x10\x00\x12\r\n\tHIGH_PERF\x10\x01\x12\x0f\n\x0bLOW_LATENCY\x10\x02\x12\t\n\x05OTHER\x10\x03\"^\n\x10\x43\x65llServiceState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tEMERGENCY\x10\x01\x12\x0b\n\x07NOMINAL\x10\x02\x12\x12\n\x0eOUT_OF_SERVICE\x10\x03\x12\r\n\tPOWER_OFF\x10\x04\"O\n\nPowerState\x12\x17\n\x13UNKNOWN_POWER_STATE\x10\x00\x12\r\n\tUNPLUGGED\x10\x01\x12\x0c\n\x08\x43HARGING\x10\x02\x12\x0b\n\x07\x43HARGED\x10\x03\"F\n\x0bScreenState\x12\x18\n\x14UNKNOWN_SCREEN_STATE\x10\x00\x12\x06\n\x02ON\x10\x01\x12\x07\n\x03OFF\x10\x02\x12\x0c\n\x08HEADLESS\x10\x03\x1a\xe9\x0f\n\x0b\x41ppSettings\x12i\n\x13\x61udio_sampling_rate\x18\x01 \x01(\x0e\x32L.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.AudioSamplingRate\x12\x1a\n\x12samples_per_window\x18\x02 \x01(\x02\x12i\n\x13\x61udio_source_tuning\x18\x03 \x01(\x0e\x32L.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.AudioSourceTuning\x12h\n\x18\x61\x64\x64itional_input_sensors\x18\x04 \x03(\x0e\x32\x46.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.InputSensor\x12\x1c\n\x14\x61utomatically_record\x18\x05 \x01(\x08\x12\x1a\n\x12launch_at_power_up\x18\x06 \x01(\x08\x12\x12\n\nstation_id\x18\x07 \x01(\t\x12\x1b\n\x13station_description\x18\x08 \x01(\t\x12\x16\n\x0epush_to_server\x18\t \x01(\x08\x12\x1f\n\x17publish_data_as_private\x18\n \x01(\x08\x12\x1b\n\x13scramble_audio_data\x18\x0b \x01(\x08\x12\x18\n\x10provide_backfill\x18\x0c \x01(\x08\x12\x1f\n\x17remove_sensor_dc_offset\x18\r \x01(\x08\x12Z\n\x0b\x66\x66t_overlap\x18\x0e \x01(\x0e\x32\x45.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.FftOverlap\x12#\n\x1buse_custom_time_sync_server\x18\x0f \x01(\x08\x12\x1c\n\x14time_sync_server_url\x18\x10 \x01(\t\x12\x1e\n\x16use_custom_data_server\x18\x11 \x01(\x08\x12\x17\n\x0f\x64\x61ta_server_url\x18\x12 \x01(\t\x12\x1e\n\x16use_custom_auth_server\x18\x13 \x01(\x08\x12\x17\n\x0f\x61uth_server_url\x18\x14 \x01(\t\x12\x1e\n\x16\x61uto_delete_data_files\x18\x15 \x01(\x08\x12\x1f\n\x17storage_space_allowance\x18\x16 \x01(\x02\x12$\n\x1cuse_sd_card_for_data_storage\x18\x17 \x01(\x08\x12\x1d\n\x15use_location_services\x18\x18 \x01(\x08\x12\x14\n\x0cuse_latitude\x18\x19 \x01(\x01\x12\x15\n\ruse_longitude\x18\x1a \x01(\x01\x12\x14\n\x0cuse_altitude\x18\x1b \x01(\x02\x12P\n\x0cmetrics_rate\x18\x1c \x01(\x0e\x32:.redvox_api_m.RedvoxPacketM.StationInformation.MetricsRate\x12Z\n\x08metadata\x18\x1d \x03(\x0b\x32H.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\nFftOverlap\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nPERCENT_25\x10\x01\x12\x0e\n\nPERCENT_50\x10\x02\x12\x0e\n\nPERCENT_75\x10\x03\"n\n\x11\x41udioSamplingRate\x12\x19\n\x15UNKNOWN_SAMPLING_RATE\x10\x00\x12\t\n\x05HZ_80\x10\x01\x12\n\n\x06HZ_800\x10\x02\x12\x0b\n\x07HZ_8000\x10\x03\x12\x0c\n\x08HZ_16000\x10\x04\x12\x0c\n\x08HZ_48000\x10\x05\"f\n\x11\x41udioSourceTuning\x12\x12\n\x0eUNKNOWN_TUNING\x10\x00\x12\x15\n\x11INFRASOUND_TUNING\x10\x01\x12\x14\n\x10LOW_AUDIO_TUNING\x10\x02\x12\x10\n\x0c\x41UDIO_TUNING\x10\x03\"\xa5\x03\n\x0bInputSensor\x12\x12\n\x0eUNKNOWN_SENSOR\x10\x00\x12\x11\n\rACCELEROMETER\x10\x01\x12\x16\n\x12\x41\x43\x43\x45LEROMETER_FAST\x10\x02\x12\x17\n\x13\x41MBIENT_TEMPERATURE\x10\x03\x12\t\n\x05\x41UDIO\x10\x04\x12\x14\n\x10\x43OMPRESSED_AUDIO\x10\x05\x12\x0b\n\x07GRAVITY\x10\x06\x12\r\n\tGYROSCOPE\x10\x07\x12\x12\n\x0eGYROSCOPE_FAST\x10\x08\x12\x14\n\x10IMAGE_PER_SECOND\x10\t\x12\x14\n\x10IMAGE_PER_PACKET\x10\n\x12\t\n\x05LIGHT\x10\x0b\x12\x17\n\x13LINEAR_ACCELERATION\x10\x0c\x12\x0c\n\x08LOCATION\x10\r\x12\x10\n\x0cMAGNETOMETER\x10\x0e\x12\x15\n\x11MAGNETOMETER_FAST\x10\x0f\x12\x0f\n\x0bORIENTATION\x10\x10\x12\x0c\n\x08PRESSURE\x10\x11\x12\r\n\tPROXIMITY\x10\x12\x12\x15\n\x11RELATIVE_HUMIDITY\x10\x13\x12\x13\n\x0fROTATION_VECTOR\x10\x14\x12\x0c\n\x08VELOCITY\x10\x15\"O\n\x06OsType\x12\x0e\n\nUNKNOWN_OS\x10\x00\x12\x0b\n\x07\x41NDROID\x10\x01\x12\x07\n\x03IOS\x10\x02\x12\x07\n\x03OSX\x10\x03\x12\t\n\x05LINUX\x10\x04\x12\x0b\n\x07WINDOWS\x10\x05\"D\n\x0bMetricsRate\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fONCE_PER_SECOND\x10\x01\x12\x13\n\x0fONCE_PER_PACKET\x10\x02\x1a\xc0\x07\n\x11TimingInformation\x12!\n\x19packet_start_os_timestamp\x18\x01 \x01(\x01\x12#\n\x1bpacket_start_mach_timestamp\x18\x02 \x01(\x01\x12\x1f\n\x17packet_end_os_timestamp\x18\x03 \x01(\x01\x12!\n\x19packet_end_mach_timestamp\x18\x04 \x01(\x01\x12,\n$server_acquisition_arrival_timestamp\x18\x05 \x01(\x01\x12 \n\x18\x61pp_start_mach_timestamp\x18\x06 \x01(\x01\x12T\n\x0fsynch_exchanges\x18\x07 \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange\x12\x14\n\x0c\x62\x65st_latency\x18\x08 \x01(\x02\x12\x13\n\x0b\x62\x65st_offset\x18\t \x01(\x02\x12\r\n\x05score\x18\n \x01(\x02\x12U\n\x0cscore_method\x18\x0b \x01(\x0e\x32?.redvox_api_m.RedvoxPacketM.TimingInformation.TimingScoreMethod\x12.\n\x04unit\x18\x0c \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12M\n\x08metadata\x18\r \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.TimingInformation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x95\x02\n\rSynchExchange\x12\n\n\x02\x61\x31\x18\x01 \x01(\x01\x12\n\n\x02\x61\x32\x18\x02 \x01(\x01\x12\n\n\x02\x61\x33\x18\x03 \x01(\x01\x12\n\n\x02\x62\x31\x18\x04 \x01(\x01\x12\n\n\x02\x62\x32\x18\x05 \x01(\x01\x12\n\n\x02\x62\x33\x18\x06 \x01(\x01\x12.\n\x04unit\x18\x07 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12[\n\x08metadata\x18\x08 \x03(\x0b\x32I.redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\" \n\x11TimingScoreMethod\x12\x0b\n\x07UNKNOWN\x10\x00\x1a\xa8\x30\n\x07Sensors\x12>\n\raccelerometer\x18\x01 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12G\n\x13\x61mbient_temperature\x18\x02 \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12\x38\n\x05\x61udio\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.Sensors.Audio\x12M\n\x10\x63ompressed_audio\x18\x04 \x01(\x0b\x32\x33.redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio\x12\x38\n\x07gravity\x18\x05 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12:\n\tgyroscope\x18\x06 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12\x38\n\x05image\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.Sensors.Image\x12\x39\n\x05light\x18\x08 \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12\x44\n\x13linear_acceleration\x18\t \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12>\n\x08location\x18\n \x01(\x0b\x32,.redvox_api_m.RedvoxPacketM.Sensors.Location\x12=\n\x0cmagnetometer\x18\x0b \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12<\n\x0borientation\x18\x0c \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12<\n\x08pressure\x18\r \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12=\n\tproximity\x18\x0e \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12\x45\n\x11relative_humidity\x18\x0f \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12@\n\x0frotation_vector\x18\x10 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12\x39\n\x08velocity\x18\x11 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12\x43\n\x08metadata\x18\x12 \x03(\x0b\x32\x31.redvox_api_m.RedvoxPacketM.Sensors.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd3\x02\n\x05\x41udio\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12\x1e\n\x16\x66irst_sample_timestamp\x18\x02 \x01(\x01\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x02\x12\x19\n\x11\x62its_of_precision\x18\x04 \x01(\x02\x12\x14\n\x0cis_scrambled\x18\x05 \x01(\x08\x12\x10\n\x08\x65ncoding\x18\x06 \x01(\t\x12:\n\x07samples\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12I\n\x08metadata\x18\x08 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.Sensors.Audio.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x8d\x03\n\x0f\x43ompressedAudio\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12\x1e\n\x16\x66irst_sample_timestamp\x18\x02 \x01(\x01\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x02\x12\x14\n\x0cis_scrambled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61udio_bytes\x18\x05 \x01(\x0c\x12S\n\x0b\x61udio_codec\x18\x06 \x01(\x0e\x32>.redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.AudioCodec\x12S\n\x08metadata\x18\x07 \x03(\x0b\x32\x41.redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\nAudioCodec\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x46LAC\x10\x01\x1a\x9c\x02\n\x06Single\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12:\n\x07samples\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32\x38.redvox_api_m.RedvoxPacketM.Sensors.Single.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd6\x18\n\x08Location\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12\x41\n\x0etimestamps_gps\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12I\n\x10latitude_samples\x18\x04 \x01(\x0b\x32/.redvox_api_m.RedvoxPacketM.DoubleSamplePayload\x12J\n\x11longitude_samples\x18\x05 \x01(\x0b\x32/.redvox_api_m.RedvoxPacketM.DoubleSamplePayload\x12\x43\n\x10\x61ltitude_samples\x18\x06 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12@\n\rspeed_samples\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x42\n\x0f\x62\x65\x61ring_samples\x18\x08 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12N\n\x1bhorizontal_accuracy_samples\x18\t \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12L\n\x19vertical_accuracy_samples\x18\n \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12I\n\x16speed_accuracy_samples\x18\x0b \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12K\n\x18\x62\x65\x61ring_accuracy_samples\x18\x0c \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12U\n\x12last_best_location\x18\r \x01(\x0b\x32\x39.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation\x12X\n\x15overall_best_location\x18\x0e \x01(\x0b\x32\x39.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation\x12$\n\x1clocation_permissions_granted\x18\x0f \x01(\x08\x12#\n\x1blocation_services_requested\x18\x10 \x01(\x08\x12!\n\x19location_services_enabled\x18\x11 \x01(\x08\x12Y\n\x12location_providers\x18\x12 \x03(\x0e\x32=.redvox_api_m.RedvoxPacketM.Sensors.Location.LocationProvider\x12L\n\x08metadata\x18\x13 \x03(\x0b\x32:.redvox_api_m.RedvoxPacketM.Sensors.Location.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xcf\r\n\x0c\x42\x65stLocation\x12m\n\x1clatitude_longitude_timestamp\x18\x01 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12\x63\n\x12\x61ltitude_timestamp\x18\x02 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12`\n\x0fspeed_timestamp\x18\x03 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12\x62\n\x11\x62\x65\x61ring_timestamp\x18\x04 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12\x41\n\x17latitude_longitude_unit\x18\x05 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x37\n\raltitude_unit\x18\x06 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x34\n\nspeed_unit\x18\x07 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x36\n\x0c\x62\x65\x61ring_unit\x18\x08 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12@\n\x16vertical_accuracy_unit\x18\t \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x42\n\x18horizontal_accuracy_unit\x18\n \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12=\n\x13speed_accuracy_unit\x18\x0b \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12?\n\x15\x62\x65\x61ring_accuracy_unit\x18\x0c \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x10\n\x08latitude\x18\r \x01(\x01\x12\x11\n\tlongitude\x18\x0e \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x0f \x01(\x02\x12\r\n\x05speed\x18\x10 \x01(\x02\x12\x0f\n\x07\x62\x65\x61ring\x18\x11 \x01(\x02\x12\x19\n\x11vertical_accuracy\x18\x12 \x01(\x02\x12\x1b\n\x13horizontal_accuracy\x18\x13 \x01(\x02\x12\x16\n\x0espeed_accuracy\x18\x14 \x01(\x02\x12\x18\n\x10\x62\x65\x61ring_accuracy\x18\x15 \x01(\x02\x12\r\n\x05score\x18\x16 \x01(\x02\x12]\n\x06method\x18\x17 \x01(\x0e\x32M.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.LocationScoreMethod\x12X\n\x11location_provider\x18\x18 \x01(\x0e\x32=.redvox_api_m.RedvoxPacketM.Sensors.Location.LocationProvider\x12Y\n\x08metadata\x18\x19 \x03(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf4\x01\n\rBestTimestamp\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x0c\n\x04mach\x18\x02 \x01(\x01\x12\x0b\n\x03gps\x18\x03 \x01(\x01\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x13LocationScoreMethod\x12\x12\n\x0eUNKNOWN_METHOD\x10\x00\"I\n\x10LocationProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x08\n\x04USER\x10\x02\x12\x07\n\x03GPS\x10\x03\x12\x0b\n\x07NETWORK\x10\x04\x1a\x94\x03\n\x03Xyz\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12<\n\tx_samples\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12<\n\ty_samples\x18\x04 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12<\n\tz_samples\x18\x05 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12G\n\x08metadata\x18\x06 \x03(\x0b\x32\x35.redvox_api_m.RedvoxPacketM.Sensors.Xyz.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf0\x02\n\x05Image\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12\x0f\n\x07samples\x18\x03 \x03(\x0c\x12I\n\x0bimage_codec\x18\x04 \x01(\x0e\x32\x34.redvox_api_m.RedvoxPacketM.Sensors.Image.ImageCodec\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.Sensors.Image.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\nImageCodec\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03PNG\x10\x01\x12\x07\n\x03JPG\x10\x02\x12\x07\n\x03\x42MP\x10\x03\x1a\xf2\x07\n\x0b\x45ventStream\x12\x0c\n\x04name\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12=\n\x06\x65vents\x18\x03 \x03(\x0b\x32-.redvox_api_m.RedvoxPacketM.EventStream.Event\x12G\n\x08metadata\x18\x04 \x03(\x0b\x32\x35.redvox_api_m.RedvoxPacketM.EventStream.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xdc\x05\n\x05\x45vent\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12X\n\x0estring_payload\x18\x02 \x03(\x0b\x32@.redvox_api_m.RedvoxPacketM.EventStream.Event.StringPayloadEntry\x12Z\n\x0fnumeric_payload\x18\x03 \x03(\x0b\x32\x41.redvox_api_m.RedvoxPacketM.EventStream.Event.NumericPayloadEntry\x12Z\n\x0f\x62oolean_payload\x18\x04 \x03(\x0b\x32\x41.redvox_api_m.RedvoxPacketM.EventStream.Event.BooleanPayloadEntry\x12T\n\x0c\x62yte_payload\x18\x05 \x03(\x0b\x32>.redvox_api_m.RedvoxPacketM.EventStream.Event.BytePayloadEntry\x12M\n\x08metadata\x18\x06 \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.EventStream.Event.MetadataEntry\x1a\x34\n\x12StringPayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13NumericPayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x35\n\x13\x42ooleanPayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x32\n\x10\x42ytePayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x94\x02\n\rSamplePayload\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x0e\n\x06values\x18\x02 \x03(\x02\x12G\n\x10value_statistics\x18\x03 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.SummaryStatistics\x12I\n\x08metadata\x18\x04 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.SamplePayload.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xa0\x02\n\x13\x44oubleSamplePayload\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x0e\n\x06values\x18\x02 \x03(\x01\x12G\n\x10value_statistics\x18\x03 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.SummaryStatistics\x12O\n\x08metadata\x18\x04 \x03(\x0b\x32=.redvox_api_m.RedvoxPacketM.DoubleSamplePayload.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd1\x02\n\rTimingPayload\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x12\n\ntimestamps\x18\x02 \x03(\x01\x12K\n\x14timestamp_statistics\x18\x03 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.SummaryStatistics\x12\x18\n\x10mean_sample_rate\x18\x04 \x01(\x02\x12\x19\n\x11stdev_sample_rate\x18\x05 \x01(\x02\x12I\n\x08metadata\x18\x06 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.TimingPayload.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf5\x01\n\x11SummaryStatistics\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x1a\n\x12standard_deviation\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0b\n\x03max\x18\x05 \x01(\x01\x12\r\n\x05range\x18\x06 \x01(\x01\x12M\n\x08metadata\x18\x07 \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.SummaryStatistics.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x03\n\x04Unit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x1d\n\x19METERS_PER_SECOND_SQUARED\x10\x01\x12\x0e\n\nKILOPASCAL\x10\x02\x12\x16\n\x12RADIANS_PER_SECOND\x10\x03\x12\x13\n\x0f\x44\x45\x43IMAL_DEGREES\x10\x04\x12\n\n\x06METERS\x10\x05\x12\x15\n\x11METERS_PER_SECOND\x10\x06\x12\x0e\n\nMICROTESLA\x10\x07\x12\x19\n\x15LSB_PLUS_MINUS_COUNTS\x10\x08\x12!\n\x1dMICROSECONDS_SINCE_UNIX_EPOCH\x10\t\x12\x0b\n\x07\x44\x45\x43IBEL\x10\n\x12\x13\n\x0f\x44\x45GREES_CELSIUS\x10\x0b\x12\x08\n\x04\x42YTE\x10\x0c\x12\x0e\n\nPERCENTAGE\x10\r\x12\x0b\n\x07RADIANS\x10\x0e\x12\x10\n\x0cMICROAMPERES\x10\x0f\x12\x0f\n\x0b\x43\x45NTIMETERS\x10\x10\x12\x15\n\x11NORMALIZED_COUNTS\x10\x11\x12\x07\n\x03LUX\x10\x12\x12\x0c\n\x08UNITLESS\x10\x13\x12\x07\n\x03PCM\x10\x14\"\xac\x01\n\x16\x45ncryptedRedvoxPacketM\x12\x0e\n\x06header\x18\x01 \x01(\x0c\x12\x0e\n\x06packet\x18\x02 \x01(\x0c\x1ar\n\x06Header\x12\x12\n\nstation_id\x18\x01 \x01(\t\x12\x14\n\x0cstation_uuid\x18\x02 \x01(\t\x12\x12\n\nauth_token\x18\x03 \x01(\t\x12\x16\n\x0e\x66irebase_token\x18\x04 \x01(\t\x12\x12\n\nauth_email\x18\x05 \x01(\t\"\x89\x01\n\x12\x41\x63quisitionRequest\x12\x12\n\nauth_token\x18\x01 \x01(\t\x12\x16\n\x0e\x66irebase_token\x18\x02 \x01(\t\x12\x10\n\x08\x63hecksum\x18\x03 \x01(\x03\x12\x14\n\x0cis_encrypted\x18\x04 \x01(\x08\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12\x0e\n\x06seq_id\x18\x06 \x01(\x03\"\xf5\x01\n\x13\x41\x63quisitionResponse\x12\x45\n\rresponse_type\x18\x01 \x01(\x0e\x32..redvox_api_m.AcquisitionResponse.ResponseType\x12\x10\n\x08\x63hecksum\x18\x02 \x01(\x03\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\x12\x0e\n\x06resend\x18\x04 \x01(\x08\x12\x0e\n\x06seq_id\x18\x05 \x01(\x03\"T\n\x0cResponseType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0e\n\nAUTH_ERROR\x10\x02\x12\x0e\n\nDATA_ERROR\x10\x03\x12\x0f\n\x0bOTHER_ERROR\x10\x04\"\\\n\x0cSynchRequest\x12\x12\n\nstation_id\x18\x01 \x01(\t\x12\x14\n\x0cstation_uuid\x18\x02 \x01(\t\x12\x0e\n\x06seq_id\x18\x03 \x01(\r\x12\x12\n\nsub_seq_id\x18\x04 \x01(\r\"\x85\x01\n\rSynchResponse\x12\x12\n\nstation_id\x18\x01 \x01(\t\x12\x14\n\x0cstation_uuid\x18\x02 \x01(\t\x12\x0e\n\x06seq_id\x18\x03 \x01(\r\x12\x12\n\nsub_seq_id\x18\x04 \x01(\r\x12\x12\n\nrecv_ts_us\x18\x05 \x01(\x04\x12\x12\n\nsend_ts_us\x18\x06 \x01(\x04\x42\x10\n\x0eio.redvox.apisb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'src.redvox_api_m.redvox_api_m_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016io.redvox.apis'
  _REDVOXPACKETM_METADATAENTRY._options = None
  _REDVOXPACKETM_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY._options = None
  _REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY._options = None
  _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY._options = None
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY._options = None
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY._options = None
  _REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY._options = None
  _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY._options = None
  _REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_EVENTSTREAM_METADATAENTRY._options = None
  _REDVOXPACKETM_EVENTSTREAM_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY._options = None
  _REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY._options = None
  _REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY._options = None
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY._options = None
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY._options = None
  _REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY._options = None
  _REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY._options = None
  _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY._options = None
  _REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY._options = None
  _REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY._serialized_options = b'8\001'
  _REDVOXPACKETM._serialized_start=54
  _REDVOXPACKETM._serialized_end=14882
  _REDVOXPACKETM_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_STATIONINFORMATION._serialized_start=482
  _REDVOXPACKETM_STATIONINFORMATION._serialized_end=5171
  _REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS._serialized_start=1107
  _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS._serialized_end=1332
  _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS._serialized_start=1335
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS._serialized_end=2992
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_NETWORKTYPE._serialized_start=2589
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_NETWORKTYPE._serialized_end=2674
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_WIFIWAKELOCK._serialized_start=2676
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_WIFIWAKELOCK._serialized_end=2743
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_CELLSERVICESTATE._serialized_start=2745
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_CELLSERVICESTATE._serialized_end=2839
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_POWERSTATE._serialized_start=2841
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_POWERSTATE._serialized_end=2920
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_SCREENSTATE._serialized_start=2922
  _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_SCREENSTATE._serialized_end=2992
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS._serialized_start=2995
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS._serialized_end=5020
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_FFTOVERLAP._serialized_start=4307
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_FFTOVERLAP._serialized_end=4380
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSAMPLINGRATE._serialized_start=4382
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSAMPLINGRATE._serialized_end=4492
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSOURCETUNING._serialized_start=4494
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSOURCETUNING._serialized_end=4596
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_INPUTSENSOR._serialized_start=4599
  _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_INPUTSENSOR._serialized_end=5020
  _REDVOXPACKETM_STATIONINFORMATION_OSTYPE._serialized_start=5022
  _REDVOXPACKETM_STATIONINFORMATION_OSTYPE._serialized_end=5101
  _REDVOXPACKETM_STATIONINFORMATION_METRICSRATE._serialized_start=5103
  _REDVOXPACKETM_STATIONINFORMATION_METRICSRATE._serialized_end=5171
  _REDVOXPACKETM_TIMINGINFORMATION._serialized_start=5174
  _REDVOXPACKETM_TIMINGINFORMATION._serialized_end=6134
  _REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE._serialized_start=5823
  _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE._serialized_end=6100
  _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_TIMINGINFORMATION_TIMINGSCOREMETHOD._serialized_start=6102
  _REDVOXPACKETM_TIMINGINFORMATION_TIMINGSCOREMETHOD._serialized_end=6134
  _REDVOXPACKETM_SENSORS._serialized_start=6137
  _REDVOXPACKETM_SENSORS._serialized_end=12321
  _REDVOXPACKETM_SENSORS_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_AUDIO._serialized_start=7356
  _REDVOXPACKETM_SENSORS_AUDIO._serialized_end=7695
  _REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO._serialized_start=7698
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO._serialized_end=8095
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_AUDIOCODEC._serialized_start=8060
  _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_AUDIOCODEC._serialized_end=8095
  _REDVOXPACKETM_SENSORS_SINGLE._serialized_start=8098
  _REDVOXPACKETM_SENSORS_SINGLE._serialized_end=8382
  _REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_LOCATION._serialized_start=8385
  _REDVOXPACKETM_SENSORS_LOCATION._serialized_end=11543
  _REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION._serialized_start=9725
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION._serialized_end=11468
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP._serialized_start=11181
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP._serialized_end=11425
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_LOCATIONSCOREMETHOD._serialized_start=11427
  _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_LOCATIONSCOREMETHOD._serialized_end=11468
  _REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER._serialized_start=11470
  _REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER._serialized_end=11543
  _REDVOXPACKETM_SENSORS_XYZ._serialized_start=11546
  _REDVOXPACKETM_SENSORS_XYZ._serialized_end=11950
  _REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_IMAGE._serialized_start=11953
  _REDVOXPACKETM_SENSORS_IMAGE._serialized_end=12321
  _REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SENSORS_IMAGE_IMAGECODEC._serialized_start=12269
  _REDVOXPACKETM_SENSORS_IMAGE_IMAGECODEC._serialized_end=12321
  _REDVOXPACKETM_EVENTSTREAM._serialized_start=12324
  _REDVOXPACKETM_EVENTSTREAM._serialized_end=13334
  _REDVOXPACKETM_EVENTSTREAM_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_EVENTSTREAM_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_EVENTSTREAM_EVENT._serialized_start=12602
  _REDVOXPACKETM_EVENTSTREAM_EVENT._serialized_end=13334
  _REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY._serialized_start=13071
  _REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY._serialized_end=13123
  _REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY._serialized_start=13125
  _REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY._serialized_end=13178
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY._serialized_start=13180
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY._serialized_end=13233
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY._serialized_start=13235
  _REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY._serialized_end=13285
  _REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SAMPLEPAYLOAD._serialized_start=13337
  _REDVOXPACKETM_SAMPLEPAYLOAD._serialized_end=13613
  _REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD._serialized_start=13616
  _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD._serialized_end=13904
  _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_TIMINGPAYLOAD._serialized_start=13907
  _REDVOXPACKETM_TIMINGPAYLOAD._serialized_end=14244
  _REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_SUMMARYSTATISTICS._serialized_start=14247
  _REDVOXPACKETM_SUMMARYSTATISTICS._serialized_end=14492
  _REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY._serialized_start=432
  _REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY._serialized_end=479
  _REDVOXPACKETM_UNIT._serialized_start=14495
  _REDVOXPACKETM_UNIT._serialized_end=14882
  _ENCRYPTEDREDVOXPACKETM._serialized_start=14885
  _ENCRYPTEDREDVOXPACKETM._serialized_end=15057
  _ENCRYPTEDREDVOXPACKETM_HEADER._serialized_start=14943
  _ENCRYPTEDREDVOXPACKETM_HEADER._serialized_end=15057
  _ACQUISITIONREQUEST._serialized_start=15060
  _ACQUISITIONREQUEST._serialized_end=15197
  _ACQUISITIONRESPONSE._serialized_start=15200
  _ACQUISITIONRESPONSE._serialized_end=15445
  _ACQUISITIONRESPONSE_RESPONSETYPE._serialized_start=15361
  _ACQUISITIONRESPONSE_RESPONSETYPE._serialized_end=15445
  _SYNCHREQUEST._serialized_start=15447
  _SYNCHREQUEST._serialized_end=15539
  _SYNCHRESPONSE._serialized_start=15542
  _SYNCHRESPONSE._serialized_end=15675
# @@protoc_insertion_point(module_scope)
